"""
All functions for getting input.
所有用来获取输入的函数。
"""

from platform import system

if system() == 'Windows':
	del system

	from .color import *
	from .output import all_colors, computer_language

	def GetBlackInput(prompt=''):
		"""
		Get balck input.
		获取黑色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_BLACK | BACKGROUND_WHITE)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetBlueInput(prompt=''):
		"""
		Get blue input.
		获取蓝色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_BLUE)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetGreenInput(prompt=''):
		"""
		Get green input.
		获取绿色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_GREEN)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetLightGreenInput(prompt='', color_number=1):
		"""
		Get light green input.
		获取浅绿色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		if color_number == 1:
			set_cmd_text_color(FOREGROUND_LIGHT_GREEN)
			input_text = input(prompt)
			resetColor()
		elif color_number == 2:
			set_cmd_text_color(FOREGROUND_LIGHT_GREEN_TWO)
			input_text = input(prompt)
			resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetRedInput(prompt=''):
		"""
		Get red input.
		获取红色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_RED)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetPurpleInput(prompt=''):
		"""
		Get purple input.
		获取紫色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_PURPLE)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetYellowInput(prompt=''):
		"""
		Get yellow input.
		获取黄色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_YELLOW)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetWhiteInput(prompt=''):
		"""
		Get white input.
		获取白色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_WHITE)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetGreyInput(prompt=''):
		"""
		Get grey input.
		获取灰色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_GREY)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetGrayInput(prompt=''):
		"""
		Get gray input.
		获取灰色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_GREY)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetLightBlueInput(prompt=''):
		"""
		Get light blue input.
		获取浅蓝色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_LIGHT_BLUE)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetVeryLightGreenInput(prompt=''):
		"""
		Get very light green input.
		获取很浅的浅绿色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_VERY_LIGHT_GREEN)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetLightRedInput(prompt=''):
		"""
		Get light red input.
		获取浅红色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_LIGHT_RED)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetLightPurpleInput(prompt=''):
		"""
		Get light purple input.
		获取浅紫色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_LIGHT_PURPLE)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetLightYellowInput(prompt=''):
		"""
		Get light yellow input.
		获取浅黄色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_LIGHT_YELLOW)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetGlossWhiteInput(prompt=''):
		"""
		Get gloss white input.
		获取亮白色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_GLOSS_WHITE)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetOtherColorInput(prompt='', text_color=FOREGROUND_WHITE, background_color=BACKGROUND_BLACK):
		"""
		Get other colors input.
		获取其他颜色的输入。
		"""
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(text_color | background_color)
		input_text = input(prompt)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor
		return input_text

	def GetInput(prompt='', text_color=FOREGROUND_WHITE, background_color=BACKGROUND_BLACK):
		"""
		Get input.
		获取输入。
		"""
		input_text = GetOtherColorInput(prompt, text_color = text_color, background_color = background_color)
		return input_text

else:
	del system



"""
All color variables.
所有颜色变量。
"""

from platform import system

if system() == 'Windows':
	del system

	# 字体颜色定义 text colors
	FOREGROUND_BLACK =             0x00 # black                   a
	FOREGROUND_BLUE =              0x01 # blue                    a
	FOREGROUND_GREEN =             0x02 # green                   a
	FOREGROUND_LIGHT_GREEN =       0x03 # light_green             a
	FOREGROUND_RED =               0x04 # red                     a
	FOREGROUND_PURPLE =            0x05 # purple                  a
	FOREGROUND_YELLOW =            0x06 # yellow                  a
	FOREGROUND_WHITE =             0x07 # white                   a
	FOREGROUND_GREY =              0x08 # grey                    a
	FOREGROUND_LIGHT_BLUE =        0x09 # light_blue              a
	FOREGROUND_LIGHT_GREEN_TWO =   0x0a # another_light_green     a
	FOREGROUND_VERY_LIGHT_GREEN =  0x0b # very_light_green        a
	FOREGROUND_LIGHT_RED =         0x0c # light_red               a
	FOREGROUND_LIGHT_PURPLE =      0x0d # light_purple            a
	FOREGROUND_LIGHT_YELLOW =      0x0e # light_yellow            a
	FOREGROUND_GLOSS_WHITE =       0x0f # gloss_white             a

	# 背景颜色定义 background colors
	BACKGROUND_BLACK =             0x00 # balck
	BACKGROUND_BLUE =              0x10 # blue
	BACKGROUND_GREEN =             0x20 # green
	BACKGROUND_LIGHT_GREEN =       0x30 # light_green
	BACKGROUND_RED =               0x40 # red
	BACKGROUND_PURPLE =            0x50 # purple
	BACKGROUND_YELLOW =            0x60 # yellow
	BACKGROUND_WHITE =             0x70 # white
	BACKGROUND_GREY =              0x80 # grey
	BACKGROUND_LIGHT_BLUE =        0x90 # light_blue
	BACKGROUND_LIGHT_GREEN_TWO =   0xa0 # another_light_green
	BACKGROUND_VERY_LIGHT_GREEN =  0xb0 # very_light_green
	BACKGROUND_LIGHT_RED =         0xc0 # light_red
	BACKGROUND_LIGHT_PURPLE =      0xd0 # light_purple
	BACKGROUND_LIGHT_YELLOW =      0xe0 # light_yellow
	BACKGROUND_GLOSS_WHITE =       0xf0 # gloss_white

else:
	del system



"""
All functions for setting CMD text color.
所有用来设置CMD（命令提示符）的文本颜色的函数。
"""

from platform import system

if system() == 'Windows':
	from .handles import STD_OUTPUT_HANDLE, STD_INPUT_HANDLE, STD_ERROR_HANDLE
	import ctypes
	del system

	std_out_handle = ctypes.windll.kernel32.GetStdHandle(STD_OUTPUT_HANDLE)
	std_error_handle = ctypes.windll.kernel32.GetStdHandle(STD_ERROR_HANDLE)
	std_input_handle = ctypes.windll.kernel32.GetStdHandle(STD_INPUT_HANDLE)
	
	del ctypes
	del STD_OUTPUT_HANDLE, STD_INPUT_HANDLE, STD_ERROR_HANDLE
	
	def set_cmd_text_color(color, handle = std_out_handle):
		"""
		Set the text color of CMD.
		设置CMD（命令提示符）的文本的颜色。
		"""
		import ctypes
		Bool = ctypes.windll.kernel32.SetConsoleTextAttribute(handle, color)
		del ctypes
		return Bool
	
	def resetColor(handle = std_out_handle):
		"""
		Restore the text color of CMD to white.
		将CMD（命令提示符）的文本颜色恢复为白色。
		"""
		from .color import FOREGROUND_RED, FOREGROUND_GREEN, FOREGROUND_BLUE
		set_cmd_text_color(FOREGROUND_RED | FOREGROUND_GREEN | FOREGROUND_BLUE, handle = handle)
		del FOREGROUND_RED, FOREGROUND_GREEN, FOREGROUND_BLUE

else:
	del system



"""
All handles variables.
所有句柄变量。
"""

from platform import system

if system() == 'Windows':
	del system
	STD_INPUT_HANDLE = -10
	STD_OUTPUT_HANDLE = -11
	STD_ERROR_HANDLE = -12

else:
	del system

# get handle
# std_out_handle = ctypes.windll.kernel32.GetStdHandle(STD_OUTPUT_HANDLE)

# def set_cmd_text_color(color, handle=std_out_handle):
# 	Bool = ctypes.windll.kernel32.SetConsoleTextAttribute(handle, color)
# 	return Bool

# #reset white
# def resetColor():
# 	set_cmd_text_color(FOREGROUND_RED | FOREGROUND_GREEN | FOREGROUND_BLUE)



"""
This is a library for printing colored texts.
这是一个用来打印彩色文字的库。

教程见 https://pypi.org/project/color-text/3.1.3/
Tutorial see https://pypi.org/project/color-text/3.1.3/
"""

from platform import system

class _Version(str):
	def __init__(self, version):
		pass

	def init_variable(self, number_1, number_2, number_3):
		self.version_str = number_1 + '.' + number_2 + '.' + number_3
		self.version_tuple = (int(number_1), int(number_2), int(number_3))
		self.version_str_tuple = (number_1, number_2, number_3)
		self.version_list = [int(number_1), int(number_2), int(number_3)]
		self.version_str_list = [number_1, number_2, number_3]
		self.version_dict = {'first_number' : int(number_1), 'second_number' : int(number_2), 'third_number' : int(number_3)}
		self.version_str_dict = {'first_number' : number_1, 'second_number' : number_2, 'third_number' : number_3}

__version__ = '3.1.3'
version = _Version(__version__)
version.init_variable('3', '1', '3')

del _Version

if system() == 'Windows':

	from .output import PrintLightRedText, PrintYellowText, PrintRedText, PrintGreenText, PrintBlackText, PrintBlueText
	from .output import PrintGreyText, PrintGrayText, PrintLightBlueText, PrintVeryLightGreenText, PrintLightPurpleText
	from .output import PrintGlossWhiteText, PrintLightGreenText, output_example, Print, PrintOtherColorText, all_colors 
	from .output import computer_language, PrintPurpleText, PrintWhiteText, PrintLightYellowText
	from .get_input import GetBlackInput, GetBlueInput, GetGlossWhiteInput, GetGrayInput, GetGreenInput, GetGreyInput
	from .get_input import GetLightBlueInput, GetLightGreenInput, GetLightPurpleInput, GetLightRedInput, GetLightYellowInput
	from .get_input import GetPurpleInput, GetRedInput, GetVeryLightGreenInput, GetWhiteInput, GetYellowInput
	from .get_input import GetOtherColorInput, GetInput
	from .color import *
	from .functions import *
	from .handles import *

else:

	ErrorText = "This library is temporarily unavailable on the operating system you are using.\n         这个库暂时不能在你使用的操作系统上运行。"
	Error = OSError(ErrorText)
	raise Error
	del Error
	del ErrorText



import setuptools

with open("README.md", "r", encoding = "utf-8") as file_object:
	long_description = file_object.read()

setuptools.setup(
	name = "color_text",
	version = "3.1.3",
	author = "A Chinese working in FJA   一个在FJA工作的中国人",
	author_email = "colortextpackage@yandex.com",
	description = "A library for printing colored text.   一个用来打印彩色文字的库。",
	long_description = long_description,
	license = 'MIT',
	long_description_content_type = "text/markdown",
	url = None,
	packages = ['color_text'],
	zip_safe = False,
	python_requires = '>=3.0, !=3.9.*, <4.0',
	classifiers = [
		"Programming Language :: Python :: 3.8",
		"Operating System :: Microsoft :: Windows",
		"License :: OSI Approved :: MIT License"
	],
	keywords = ["color_text", "color text", "colour_text", "colour text", "彩色文字", "有颜色的文字", "颜色文字",
		"彩色文本", "有颜色的文本", "颜色文本", "color_words", "color words", "colour_words", "colour words", "color_word",
		"color word", "colour_word", "colour word"],
	platforms = ["Windows"],
	scripts = ["color_text-example.cmd"]
)



"""
All functions for output.
所有用来输出的函数。
"""

from platform import system

if system() == 'Windows':

	def _less(_all_colors):
		all_colors = []
		for color in _all_colors:
			if color == '__builtins__' or color == '__cached__' or color == '__doc__' or color == '__file__' or color == '__loader__' or color == '__name__' or color == '__package__' or color == '__spec__':
				pass
			else:
				all_colors.append(color)
		return all_colors

	all_colors = _less(dir(__import__('color_text.color')))
	del _less

	from .color import *

	import ctypes
	try:
		_dll_h = ctypes.windll.kernel32
		computer_language = hex(_dll_h.GetSystemDefaultUILanguage())
		del _dll_h
	except:
		computer_language = None

	del ctypes
	del system

	def PrintGreenText(*values, end='\n'):
		"""
		Print green text.
		打印绿色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_GREEN)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintRedText(*values, end='\n'):
		"""
		Print red text.
		打印红色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_RED)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintYellowText(*values, end='\n'):
		"""
		Print yellow text.
		打印黄色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_YELLOW)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintLightRedText(*values, end='\n'):
		"""
		Print light red text.
		打印浅红色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_LIGHT_RED)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintBlackText(*values, end='\n'):
		"""
		Print black text.
		打印黑色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_BLACK | BACKGROUND_WHITE)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintBlueText(*values, end='\n'):
		"""
		Print blue text.
		打印蓝色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_BLUE)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintLightGreenText(*values, color_number=1, end='\n'):
		"""
		Print light green text.
		打印浅绿色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		if color_number == 1:
			set_cmd_text_color(FOREGROUND_LIGHT_GREEN)
			for mess in values:
				times += 1
				if times < len(values):
					sys.stdout.write(str(mess) + ' ')
				else:
					sys.stdout.write(str(mess))
			sys.stdout.write(end)
			resetColor()
		elif color_number == 2:
			set_cmd_text_color(FOREGROUND_LIGHT_GREEN_TWO)
			for mess in values:
				times += 1
				if times < len(values):
					sys.stdout.write(str(mess) + ' ')
				else:
					sys.stdout.write(str(mess))
			sys.stdout.write(end)
			resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintPurpleText(*values, end='\n'):
		"""
		Print purple text.
		打印紫色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_PURPLE)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintWhiteText(*values, end='\n'):
		"""
		Print white text.
		打印白色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_WHITE)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintGreyText(*values, end='\n'):
		"""
		Print grey text.
		打印灰色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_GREY)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintGrayText(*values, end='\n'):
		"""
		Print gray text.
		打印灰色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_GREY)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintLightBlueText(*values, end='\n'):
		"""
		Print light blue text.
		打印浅蓝色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_LIGHT_BLUE)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintVeryLightGreenText(*values, end='\n'):
		"""
		Print very light green text.
		打印很浅的浅绿色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_VERY_LIGHT_GREEN)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintLightPurpleText(*values, end='\n'):
		"""
		Print light purple text.
		打印浅紫色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_LIGHT_PURPLE)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintLightYellowText(*values, end='\n'):
		"""
		Print light yellow text.
		打印浅黄色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_LIGHT_YELLOW)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def PrintGlossWhiteText(*values, end='\n'):
		"""
		Print gloss white text.
		打印亮白色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		set_cmd_text_color(FOREGROUND_GLOSS_WHITE)
		for mess in values:
			times += 1
			if times < len(values):
				sys.stdout.write(str(mess) + ' ')
			else:
				sys.stdout.write(str(mess))
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def Print(*values, text_color=FOREGROUND_WHITE, background_color=BACKGROUND_BLACK, end='\n'):
		"""
		Print text.
		打印文字。
		"""
		times = 0
		for value in values:
			times += 1
			if times < len(values):
				PrintOtherColorText(value, text_color = text_color, background_color = background_color, end = ' ')
			else:
				PrintOtherColorText(value, text_color = text_color, background_color = background_color, end = '')
		PrintOtherColorText('', text_color = text_color, background_color = background_color, end = end)

	def PrintOtherColorText(*values, text_color=FOREGROUND_WHITE, background_color=BACKGROUND_BLACK, end='\n'):
		"""
		Print other colors text.
		打印其他颜色的文字。
		"""
		times = 0
		from .functions import set_cmd_text_color, resetColor
		import sys
		for value in values:
			set_cmd_text_color(text_color | background_color)
			times += 1
			if times < len(values):
				sys.stdout.write(str(value) + ' ')
			else:
				sys.stdout.write(str(value))
			resetColor()
		set_cmd_text_color(text_color | background_color)
		sys.stdout.write(end)
		resetColor()
		del sys
		del set_cmd_text_color, resetColor

	def output_example(computer_language=computer_language, time_to_sleep=0):
		"""
		A Example of output.
		一个输出的例子。
		"""
		if computer_language == 0x409 or computer_language == '0x409' or computer_language == 'English' or computer_language == 'english' or computer_language == u'英文' or computer_language == u'英语' or computer_language == 1033 or computer_language == '1033':
			PrintLightRedText("This is a light red text.")
			PrintYellowText("This is a yellow text.")
			PrintRedText("This is a red text.")
			PrintGreenText("This is a green text.")
			PrintBlackText("This is a black text.")
			PrintBlueText("This is a blue text.")
			PrintPurpleText("This is a purple text.")
			PrintWhiteText("This is a white text.")
			PrintGreyText("This is a grey text.")
			PrintGrayText("This is a grey text too.")
			PrintLightBlueText("This is a light blue text.")
			PrintVeryLightGreenText("This is a very light green text.")
			PrintLightPurpleText("This is a light purple text.")
			PrintLightYellowText("This is a light yellow text.")
			PrintGlossWhiteText("This is a gloss white text.")
			PrintLightGreenText("This is a light green text.")
			PrintLightGreenText("This is a light green text too.", color_number = 2)
		elif computer_language == 0x804 or computer_language == '0x804' or computer_language == 'Chinese' or computer_language == 'chinese' or computer_language == u'中文' or computer_language == u'汉语' or computer_language == u'普通话' or computer_language == 2052 or computer_language == '2052':
			PrintLightRedText("这是一段浅红色的文字。")
			PrintYellowText("这是一段黄色的文字。")
			PrintRedText("这是一段红色的文字。")
			PrintGreenText("这是一段绿色的文字。")
			PrintBlackText("这是一段黑色的文字。")
			PrintBlueText("这是一段蓝色的文字。")
			PrintPurpleText("这是一段紫色的文字。")
			PrintWhiteText("这是一段白色的文字。")
			PrintGreyText("这是一段灰色的文字。")
			PrintGrayText("这也是一段灰色的文字。")
			PrintLightBlueText("这是一段浅蓝色的文字。")
			PrintVeryLightGreenText("这是一段很浅的绿色的文字。")
			PrintLightPurpleText("这是一段浅紫色的文字。")
			PrintLightYellowText("这是一段浅黄色的文字。")
			PrintGlossWhiteText("这是一段亮白色的文字。")
			PrintLightGreenText("这是一段浅绿色的文字。")
			PrintLightGreenText("这也是一段浅绿色的文字。", color_number = 2)
		else:
			PrintLightRedText("This is a light red text.")
			PrintYellowText("This is a yellow text.")
			PrintRedText("This is a red text.")
			PrintGreenText("This is a green text.")
			PrintBlackText("This is a black text.")
			PrintBlueText("This is a blue text.")
			PrintPurpleText("This is a purple text.")
			PrintWhiteText("This is a white text.")
			PrintGreyText("This is a grey text.")
			PrintGrayText("This is a grey text too.")
			PrintLightBlueText("This is a light blue text.")
			PrintVeryLightGreenText("This is a very light green text.")
			PrintLightPurpleText("This is a light purple text.")
			PrintLightYellowText("This is a light yellow text.")
			PrintGlossWhiteText("This is a gloss white text.")
			PrintLightGreenText("This is a light green text.")
			PrintLightGreenText("This is a light green text too.", color_number = 2)
		import time as t
		t.sleep(int(time_to_sleep))
		del t

else:
	del system

if __name__ == '__main__':
	example()
